@@ -18,7 +18,6 @@ from telebot import types
 from telebot import util
 
 logger = telebot.logger
-req_session = requests.session()
 proxy = None
 
 API_URL = "https://api.telegram.org/bot{0}/{1}"
@@ -28,6 +27,10 @@ CONNECT_TIMEOUT = 3.5
 READ_TIMEOUT = 9999
 
 
+def _get_req_session():
+    return util.per_thread('req_session', lambda: requests.session())
+
+
 def _make_request(token, method_name, method='get', params=None, files=None, base_url=API_URL):
     """
     Makes a request to the Telegram API.
@@ -47,8 +50,8 @@ def _make_request(token, method_name, method='get', params=None, files=None, bas
     if params:
         if 'timeout' in params: read_timeout = params['timeout'] + 10
         if 'connect-timeout' in params: connect_timeout = params['connect-timeout'] + 10
-    result = req_session.request(method, request_url, params=params, files=files,
-                                 timeout=(connect_timeout, read_timeout), proxies=proxy)
+    result = _get_req_session().request(method, request_url, params=params, files=files,
+                                        timeout=(connect_timeout, read_timeout), proxies=proxy)
     logger.debug("The server returned: '{0}'".format(result.text.encode('utf8')))
     return _check_result(method_name, result)['result']
 
@@ -97,7 +100,7 @@ def get_file(token, file_id):
 
 def download_file(token, file_path):
     url = FILE_URL.format(token, file_path)
-    result = req_session.get(url)
+    result = _get_req_session().get(url)
     if result.status_code != 200:
         msg = 'The server returned HTTP {0} {1}. Response body:\n[{2}]' \
             .format(result.status_code, result.reason, result.text)
@@ -434,25 +437,46 @@ def unban_chat_member(token, chat_id, user_id):
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def restrict_chat_member(token, chat_id, user_id, until_date=None, can_send_messages=True,
-                             can_send_media_messages=True, can_send_other_messages=True,
-                             can_add_web_page_previews=True):
+def restrict_chat_member(token, chat_id, user_id, until_date=None, can_send_messages=None,
+                         can_send_media_messages=None, can_send_other_messages=None,
+                         can_add_web_page_previews=None):
     method_url = 'restrictChatMember'
-    payload = {'chat_id': chat_id, 'user_id': user_id, 'until_date': until_date, 'can_send_messages': can_send_messages,
-               'can_send_media_messages': can_send_media_messages, 'can_send_other_messages': can_send_other_messages,
-               'can_add_web_page_previews': can_add_web_page_previews}
+    payload = {'chat_id': chat_id, 'user_id': user_id}
+    if until_date:
+        payload['until_date'] = until_date
+    if can_send_messages:
+        payload['can_send_messages'] = can_send_messages
+    if can_send_media_messages:
+        payload['can_send_media_messages'] = can_send_media_messages
+    if can_send_other_messages:
+        payload['can_send_other_messages'] = can_send_other_messages
+    if can_add_web_page_previews:
+        payload['can_add_web_page_previews'] = can_add_web_page_previews
+
     return _make_request(token, method_url, params=payload, method='post')
 
 
-def promote_chat_member(token, chat_id, user_id, can_change_info=False, can_post_messages=False,
-                        can_edit_messages=False, can_delete_messages=False, can_invite_users=False,
-                        can_restrict_members=False, can_pin_messages=False, can_promote_members=False):
+def promote_chat_member(token, chat_id, user_id, can_change_info=None, can_post_messages=None,
+                        can_edit_messages=None, can_delete_messages=None, can_invite_users=None,
+                        can_restrict_members=None, can_pin_messages=None, can_promote_members=None):
     method_url = 'promoteChatMember'
-    payload = {'chat_id': chat_id, 'user_id': user_id, 'can_change_info': can_change_info,
-               'can_post_messages': can_post_messages, 'can_edit_messages': can_edit_messages,
-               'can_delete_messages': can_delete_messages, 'can_invite_users': can_invite_users,
-               'can_restrict_members': can_restrict_members, 'can_pin_messages': can_pin_messages,
-               'can_promote_members': can_promote_members }
+    payload = {'chat_id': chat_id, 'user_id': user_id}
+    if can_change_info:
+        payload['can_change_info'] = can_change_info
+    if can_post_messages:
+        payload['can_post_messages'] = can_post_messages
+    if can_edit_messages:
+        payload['can_edit_messages'] = can_edit_messages
+    if can_delete_messages:
+        payload['can_delete_messages'] = can_delete_messages
+    if can_invite_users:
+        payload['can_invite_users'] = can_invite_users
+    if can_restrict_members:
+        payload['can_restrict_members'] = can_restrict_members
+    if can_pin_messages:
+        payload['can_pin_messages'] = can_pin_messages
+    if can_promote_members:
+        payload['can_promote_members'] = can_promote_members
     return _make_request(token, method_url, params=payload, method='post')
 
 
@@ -767,6 +791,58 @@ def answer_inline_query(token, inline_query_id, results, cache_time=None, is_per
     return _make_request(token, method_url, params=payload, method='post')
 
 
+def get_sticker_set(token, name):
+    method_url = 'getStickerSet'
+    return _make_request(token, method_url, params={'name': name})
+
+
+def upload_sticker_file(token, user_id, png_sticker):
+    method_url = 'uploadStickerFile'
+    payload = {'user_id': user_id}
+    files = {'png_sticker': png_sticker}
+    return _make_request(token, method_url, params=payload, files=files, method='post')
+
+
+def create_new_sticker_set(token, user_id, name, title, png_sticker, emojis, contains_masks=None, mask_position=None):
+    method_url = 'createNewStickerSet'
+    payload = {'user_id': user_id, 'name': name, 'title': title, 'emojis': emojis}
+    files = None
+    if not util.is_string(png_sticker):
+        files = {'png_sticker': png_sticker}
+    else:
+        payload['png_sticker'] = png_sticker
+    if contains_masks:
+        payload['contains_masks'] = contains_masks
+    if mask_position:
+        payload['mask_position'] = mask_position.to_json()
+    return _make_request(token, method_url, params=payload, files=files, method='post')
+
+
+def add_sticker_to_set(token, user_id, name, png_sticker, emojis, mask_position):
+    method_url = 'addStickerToSet'
+    payload = {'user_id': user_id, 'name': name, 'emojis': emojis}
+    files = None
+    if not util.is_string(png_sticker):
+        files = {'png_sticker': png_sticker}
+    else:
+        payload['png_sticker'] = png_sticker
+    if mask_position:
+        payload['mask_position'] = mask_position.to_json()
+    return _make_request(token, method_url, params=payload, files=files, method='post')
+
+
+def set_sticker_position_in_set(token, sticker, position):
+    method_url = 'setStickerPositionInSet'
+    payload = {'sticker': sticker, 'position': position}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
+def delete_sticker_from_set(token, sticker):
+    method_url = 'deleteStickerFromSet'
+    payload = {'sticker': sticker}
+    return _make_request(token, method_url, params=payload, method='post')
+
+
 def _convert_list_json_serializable(results):
     ret = ''
     for r in results:
